@@ -82,9 +82,17 @@ def completed(function_name):
     return f"{function_name} completed"
 
 
-def aux_logger(in_name):
-
-    return logging.getLogger(in_name)
+def aux_logger(in_name: str):
+    in_name = in_name.split('.', maxsplit=1)
+    in_name = in_name[-1]
+    name_length = len(in_name)
+    if name_length > 34:
+        while name_length > 31:
+            in_name = in_name.split('.', maxsplit=1)
+            in_name = in_name[-1]
+            name_length = len(in_name)
+        in_name = '..' + in_name
+    return logging.getLogger('main.' + in_name)
 
 
 def alt_aux_logger(in_name):
